#' @name SoaresEx18
#' @title Valores de Creatinina Fosfocinase (CFC) em 360 Pacientes
#' @description Em um hospital do coração, foram analisados os valores
#'     de CFC (crestinina fosfocinase) de 360 pacientes, sendo 230 com
#'     infarto agudo do miocárdio. Os dados estão agregados com as
#'     frequências em cada classe.
#' @format Um \code{data.frame} com 6 observações e 3 variáveis, em que
#'
#' \describe{
#'
#' \item{\code{cfc}}{Índice dos valores de CFC.}
#'
#' \item{\code{ia}}{Infarto agudo presente ou não presente.}
#'
#' \item{\code{freq}}{Número de pacientes em cada classe.}
#'
#' }
#' @keywords TC
#' @source SOARES; SIQUEIRA (2002), página 126, exercício 18.
#' @examples
#'
#' library(lattice)
#'
#' data(SoaresEx18)
#' str(SoaresEx18)
#'
#' coletac <- xtabs(freq ~ cfc + ia, data = SoaresEx18)
#' addmargins(coletac)
#'
#' barchart(coletac,
#'          horizontal = FALSE,
#'          stack = FALSE,
#'          scales = list(x = list(labels = c("CFC < 80",
#'                                            "80 <= CFC < 279",
#'                                            "CFC >= 279"))),
#'          ylab = "Frequência",
#'          xlab = "CFC",
#'          auto.key = list(title = "Infato do miocardio",
#'                          cex.title = 1.1,
#'                          columns = 2,
#'                          text = c("não", "sim")))
#'
#' mosaicplot(coletac)
#'
NULL
