#' @name SoaresEx19
#' @title Eficácia do Exame Clínico Neurológico
#' @description A hemorragia peri-intraventricular (HPIV) é uma das
#'     causas mais frequentes de agressão ao sistema nervoso central no
#'     período de neonatal e a segunda causa mais frequente de morte em
#'     prematuros. Atualmente, o método de escolha para diagnóstico
#'     consiste em técnicas não invasivas (ultra-sonografia e tomografia
#'     computacionalizada). Tavares (1995) estudou a ocorrência desta
#'     enfermidade em 120 dos 129 recém-nascidos com peso menor que
#'     2000 g, nascidos no Hospital das Clínias da UFMG, no peíodo de
#'     18/01/1994 a 17/05/1995. Para avaliar a eficácia do exame clínico
#'     neurológico, as crianças foram examinadas por um pediatra clínico
#'     com formação em neonatologia, sem o conhecimento prévio dos
#'     exames ultrasonográficos, que confirmam ou não diagnóstico
#'     fornecido pelo médico.
#' @format Um \code{data.frame} com 4 observações e 3 variáveis, em que
#'
#' \describe{
#'
#' \item{\code{hpiv}}{Hemorragia peri-intraventricular presente ou não.}
#'
#' \item{\code{ex}}{Exame neurológico alterado ou normal.}
#'
#' \item{\code{freq}}{Eficiência do exame.}
#'
#' }
#' @keywords TC
#' @source SOARES; SIQUEIRA (2002), página 127, exercício 19.
#' @references TAVARES, E. C. Estudo ultra-sonográfico e clínico 
#'     neurológico das hemorragias peri-intraventriculares em 
#'     recém-nascidos com peso do nascimento menor do que 200 g. Belo 
#'     Horizonte: Faculdade de Medicina da UFMG, 1995. (Dissertação, 
#'     Mestrado em Pediatria).
#' @examples
#'
#' library(lattice)
#'
#' data(SoaresEx19)
#' str(SoaresEx19)
#'
#' a <- xtabs(freq ~ hpiv + ex, data = SoaresEx19)
#' addmargins(a)
#'
#' mosaicplot(a)
#'
#' barchart(a,
#'          horizontal = FALSE,
#'          stack = FALSE,
#'          scales = list(x = list(labels = c("Ausente", "Presente"))),
#'          ylab = "Frequência",
#'          xlab = "HPIV",
#'          auto.key = list(text = c("Exame Neurológico Alterado",
#'                                   "Exame Neurológico Normal")))
#'
NULL
